pub enum Tree<T> {
Node(HashMap<String, Tree<T>>),
Leaf(T),
}Expand description
Generic type for a string-indexed tree.
Variants
Implementations
Sourceimpl<T> Tree<T>
impl<T> Tree<T>
Sourcepub fn map<U, F>(self, f: F) -> Tree<U>where
F: Fn(T) -> U,
pub fn map<U, F>(self, f: F) -> Tree<U>where
F: Fn(T) -> U,
Map every leaf element with a function, consuming this tree and returning a new one with the same structure.
Sourcepub fn map_with_path<U, F>(self, f: F) -> Tree<U>
pub fn map_with_path<U, F>(self, f: F) -> Tree<U>
Like map, but gives you an argument containing the leaf’s path.
pub fn _map_with_path<U, F>(self, f: Rc<F>, path: &mut Vec<String>) -> Tree<U>
pub fn zip<U>(self, tree: Tree<U>) -> Tree<(T, U)>
Sourcepub fn get<'a>(&'a self, path: &Vec<String>) -> Option<&'a Self>
pub fn get<'a>(&'a self, path: &Vec<String>) -> Option<&'a Self>
Get a reference to a node in the tree at the given path.
Sourcepub fn get_leaf<'a>(&'a self, path: &Vec<String>) -> Option<&'a T>
pub fn get_leaf<'a>(&'a self, path: &Vec<String>) -> Option<&'a T>
Get a reference to a leaf in the tree at the given path.
Sourcepub fn get_mut<'a>(&'a mut self, path: &Vec<String>) -> Option<&'a mut Self>
pub fn get_mut<'a>(&'a mut self, path: &Vec<String>) -> Option<&'a mut Self>
Get a mutable reference to a node in the tree at the given path.
Sourcepub fn insert(
&mut self,
path: Vec<String>,
tree: Tree<T>,
allow_overwrite: bool,
) -> bool
pub fn insert( &mut self, path: Vec<String>, tree: Tree<T>, allow_overwrite: bool, ) -> bool
Insert a subtree into the tree at the given path.
Returns whether the operation completed successfully - will fail if the insertion would have to override a preexisting part of the tree.
Sourcepub fn contains_leaf(&self, path: &Vec<String>) -> bool
pub fn contains_leaf(&self, path: &Vec<String>) -> bool
Return whether the tree contains a leaf at the given path.
Sourceimpl Tree<Namespace>
impl Tree<Namespace>
Sourcepub fn advance_path(
&self,
rel: &Vec<String>,
abs: &Vec<String>,
) -> Option<(Vec<String>, Vec<String>)>
pub fn advance_path( &self, rel: &Vec<String>, abs: &Vec<String>, ) -> Option<(Vec<String>, Vec<String>)>
Get an item given an absolute path. Advance a relative path as far as possible.
Two paths are returned: the resulting absolute path and the remainder of the relative path, which may be needed to index into the resulting item.